summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rw-r--r--Lib/webbrowser.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/Lib/webbrowser.py b/Lib/webbrowser.py
index fd8c521..759f470 100644
--- a/Lib/webbrowser.py
+++ b/Lib/webbrowser.py
@@ -104,11 +104,11 @@ class Netscape:
register("netscape", Netscape)
-class Konquerer:
- """Controller for the KDE File Manager (kfm, or Konquerer).
+class Konqueror:
+ """Controller for the KDE File Manager (kfm, or Konqueror).
See http://developer.kde.org/documentation/other/kfmclient.html
- for more information on the Konquerer remote-control interface.
+ for more information on the Konqueror remote-control interface.
"""
def _remote(self, action):
@@ -128,7 +128,7 @@ class Konquerer:
def open_new(self, url):
self._remote("openURL %s" % url)
-register("kfm", Konquerer)
+register("kfm", Konqueror)
class Grail: